import { IPublicModelPluginContext } from '@gant-lowcode/lowcode-types';
import TreeNode from './tree-node';
import { Tree } from './tree';
import { ReactNode } from 'react';
import { NotificationInstance } from 'antd/es/notification/interface';
export interface ITreeBoard {
    readonly at: string | symbol;
    scrollToNode(treeNode: TreeNode, detail?: any): void;
}
export interface IOutlinePanelPluginContext extends IPublicModelPluginContext {
    extraTitle?: string;
    intlNode(id: string, params?: object): ReactNode;
    intl(id: string, params?: object): string;
    getLocale(): string;
}
/**
 * 大纲树核心控制器，负责：
 * 1. 管理多个文档对应的大纲树实例
 * 2. 协调面板间的交互通信
 * 3. 处理全局事件与文档关联
 */
export declare class TreeMaster {
    readonly options: {
        extraTitle?: string;
    };
    pluginContext: IOutlinePanelPluginContext;
    private boards;
    private treeMap;
    private disposeEvents;
    notificationApi: NotificationInstance;
    event: any;
    constructor(pluginContext: IPublicModelPluginContext, options: {
        extraTitle?: string;
    }, notificationApi: NotificationInstance);
    setNotificationApi(api: NotificationInstance): void;
    private setPluginContext;
    private disposeEvent;
    dragCount: number;
    /**
     * 初始化全局事件监听
     * 包含：
     * - 拖拽开始/结束事件
     * - 激活节点追踪器变更事件
     * - 文档移除事件
     */
    private initEvent;
    private toVision;
    addBoard(board: ITreeBoard): void;
    removeBoard(board: ITreeBoard): void;
    purge(): void;
    onPluginContextChange(fn: () => void): void;
    emitPluginContextChange(): void;
    /**
     * 获取当前文档对应的大纲树
     * 每个文档维护独立的大纲树实例
     */
    get currentTree(): Tree | null;
}
